The [MLCommons](https://mlcommons.org), [cTuning foundation](https://cTuning.org) and [cKnowledge.org](https://cKnowledge.org) 
are preparing a unified interface to run MLPerf inference benchmark at the Student Cluster Competition'24.

See [the CM-MLPerf tutorial for SCC'23](https://github.com/mlcommons/ck/blob/master/docs/tutorials/scc23-mlperf-inference-bert.md). 
Note that the MLPerf model will change in SCC'24 - please stay tuned for more details!

See https://sc24.supercomputing.org/students/student-cluster-competition for more details about SCC.
